==> eslint-config-angular-15.0.0-beta.1.tgz: package/CHANGELOG.md <==
# Changelog (`angular-X`)

All notable changes to `@pxlwidgets/eslint-config-angular` will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

> This project does not use semantic versioning, but stays in sync with (major) Angular versions.
For example, when using Angular 12, `npm install @pxlwidgets/eslint-config-angular@12`. The minor and patch
portions of versions listed in this document _do_ follow semver with respect to this project.

<br>
<br>

## [Unreleased][unreleased]

### Changed
- Installed dependencies as required for Angular 15.

<br>
<br>

# Common history (before Angular version synchronisation)

## [1.0.0-beta.2] (2021-12-23)

### Fixed
- Added dependency `@angular-eslint/builder`
- Added dependency `@angular-eslint/schematics`

## [1.0.0-beta.1] (2021-12-20)

**Initial release.** This configuration was migrated from [another repository][old-repo] and was previously published
as a special configuration under [@pxlwidgets/eslint-config][base-config].


<!------------------------------------------------------------------------
-- Version history diffs
------------------------------------------------------------------------->

<!-- Angular 15 history -->
[unreleased]: https://gitlab.pxlwidgets.com/internal/packages/typescript-project-configurations/eslint-config-angular/-/compare/v1.0.0-beta.2...angular-15

<!-- Common history -->
[1.0.0-beta.2]: https://gitlab.pxlwidgets.com/internal/packages/typescript-project-configurations/eslint-config-angular/-/compare/v1.0.0-beta.1...v1.0.0-beta.2
[1.0.0-beta.1]: https://gitlab.pxlwidgets.com/internal/packages/typescript-project-configurations/eslint-config-angular/-/commits/v1.0.0-beta.1

<!-- Other links -->

[old-repo]: https://gitlab.pxlwidgets.com/internal/documentation/pxl.widgets-ts-style-standard
[base-config]: https://www.npmjs.com/package/@pxlwidgets/eslint-config

==> eslint-config-angular-16.0.0-beta.1.tgz: package/CHANGELOG.md <==
# Changelog (`angular-X`)

All notable changes to `@pxlwidgets/eslint-config-angular` will be documented in this file.
The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

> This project does not use semantic versioning, but stays in sync with (major) Angular versions.
For example, when using Angular 12, `npm install @pxlwidgets/eslint-config-angular@12`. The minor and patch
portions of versions listed in this document _do_ follow semver with respect to this project.

<br>
<br>

## [Unreleased][unreleased]

<br>
<br>

# Common history (before Angular version synchronisation)

## [1.0.0-beta.2] (2021-12-23)

### Fixed
- Added dependency `@angular-eslint/builder`
- Added dependency `@angular-eslint/schematics`

## [1.0.0-beta.1] (2021-12-20)

**Initial release.** This configuration was migrated from [another repository][old-repo] and was previously published
as a special configuration under [@pxlwidgets/eslint-config][base-config].


<!------------------------------------------------------------------------
-- Version history diffs 
------------------------------------------------------------------------->

<!-- Angular X history -->
[unreleased]: https://gitlab.pxlwidgets.com/internal/packages/typescript-project-configurations/eslint-config-angular/-/compare/v1.0.0-beta.2...angular-x 

<!-- Common history -->
[1.0.0-beta.2]: https://gitlab.pxlwidgets.com/internal/packages/typescript-project-configurations/eslint-config-angular/-/compare/v1.0.0-beta.1...v1.0.0-beta.2
[1.0.0-beta.1]: https://gitlab.pxlwidgets.com/internal/packages/typescript-project-configurations/eslint-config-angular/-/commits/v1.0.0-beta.1

<!-- Other links -->

[old-repo]: https://gitlab.pxlwidgets.com/internal/documentation/pxl.widgets-ts-style-standard
[base-config]: https://www.npmjs.com/package/@pxlwidgets/eslint-config
